==> babbler-script-react-0.0.2.tgz: package/lib/BabblerScriptLoad.js <==
'use strict';

var _elemental = require('elemental');

var _babblerScriptJs = require('babbler-script-js');

var _babblerScriptJs2 = _interopRequireDefault(_babblerScriptJs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// BabblerScriptLoad.js

var React = require('react');

//import BabblerScript from '../../babbler-script-js/src/babbler-script';

var btnStyle = {
    margin: 12
};

// Загрузка скрипта BabblerScript из файла
var BabblerScriptLoad = React.createClass({
    displayName: 'BabblerScriptLoad',

    // http://www.material-ui.com/#/components/table
    // https://stackoverflow.com/questions/30730369/reactjs-component-not-rendering-textarea-with-state-variable

    getInitialState: function getInitialState() {
        return {
            scriptState: this.props.babblerScript.state,
            file: '',
            err: ''
        };
    },

    componentDidMount: function componentDidMount() {
        this.programStateListener = function (state, err) {
            this.setState({ scriptState: state });
        }.bind(this);
        this.props.babblerScript.on(_babblerScriptJs2.default.Event.STATE, this.programStateListener);
    },

    componentWillUnmount: function componentWillUnmount() {
        // почистим слушателей;
        this.props.babblerScript.removeListener(_babblerScriptJs2.default.Event.STATE, this.programStateListener);
    },

    render: function render() {
        // разрешим загружать новый скрипт только в том случае, если текущий остановлен
        var stopped = this.state.scriptState === _babblerScriptJs2.default.State.STOPPED || this.state.scriptState === _babblerScriptJs2.default.State.ERROR ? true : false;

        return React.createElement(
            'span',
            { style: this.props.style },
            React.createElement('input', { id: 'fileId', type: 'file', style: { display: 'none' },
                onChange: this.load_script }),
            React.createElement(
                _elemental.Button,
                { size: 'lg', type: 'danger',
                    onClick: function onClick() {
                        document.getElementById('fileId').click();
                    },
                    disabled: !stopped,
                    style: btnStyle },
                '\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044C'
            ),
            React.createElement(
                'span',
                null,
                this.state.file
            ),
            React.createElement(
                _elemental.Button,
                { size: 'lg', type: 'danger',
                    onClick: this.load_script_debug,
                    disabled: !stopped,
                    style: btnStyle },
                '\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044C (\u043E\u0442\u043B\u0430\u0434\u043A\u0430)'
            ),
            this.state.err ? React.createElement(
                'span',
                null,
                React.createElement('br', null),
                React.createElement(
                    'span',
                    { style: { color: 'red' } },
                    'err: ',
                    this.state.err
                )
            ) : ""
        );
    },

    load_script: function load_script(e) {
        // https://stackoverflow.com/questions/39941583/electron-open-file-from-menu

        var files = e.target.files;
        var f = files[0];
        this.setState({ file: f.name });

        var reader = new FileReader();
        reader.onload = function (e) {
            var progStr = e.target.result;

            // распарсим строку в последовательность команд
            var prog = _babblerScriptJs2.default.parseStr(progStr).program;
            this.props.babblerScript.setProgram(prog);
        }.bind(this);
        reader.readAsBinaryString(f);

        // сбросим значение скрытого поля с именем файла, иначе
        // он не разрешит повторно загрузить тот же файл еще раз
        // (не вызовет событие onChange)
        e.target.value = "";
    },

    load_script_debug: function load_script_debug() {
        this.props.babblerScript.setProgram([{ cmd: "step", params: ["x", "10000", "1000"] }, { cmd: "step", params: ["y", "10000", "1000"] }, { cmd: "step", params: ["x", "-10000", "1000", "y", "-10000", "1000"] }]);
    }
});

// отправляем компонент на публику
module.exports = BabblerScriptLoad;

==> babbler-script-react-0.0.3.tgz: package/lib/BabblerScriptLoad.js <==
'use strict';

var _elemental = require('elemental');

var _babblerScriptJs = require('babbler-script-js');

var _babblerScriptJs2 = _interopRequireDefault(_babblerScriptJs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// BabblerScriptLoad.js

var React = require('react');

//import BabblerScript from '../../babbler-script-js/src/babbler-script';

var btnStyle = {
    margin: 12
};

// Загрузка скрипта BabblerScript из файла
var BabblerScriptLoad = React.createClass({
    displayName: 'BabblerScriptLoad',

    // http://www.material-ui.com/#/components/table
    // https://stackoverflow.com/questions/30730369/reactjs-component-not-rendering-textarea-with-state-variable

    getInitialState: function getInitialState() {
        return {
            scriptState: this.props.babblerScript.state,
            file: '',
            err: ''
        };
    },

    componentDidMount: function componentDidMount() {
        this.programStateListener = function (state, err) {
            this.setState({ scriptState: state });
        }.bind(this);
        this.props.babblerScript.on(_babblerScriptJs2.default.Event.STATE, this.programStateListener);
    },

    componentWillUnmount: function componentWillUnmount() {
        // почистим слушателей;
        this.props.babblerScript.removeListener(_babblerScriptJs2.default.Event.STATE, this.programStateListener);
    },

    render: function render() {
        // разрешим загружать новый скрипт только в том случае, если текущий остановлен
        var stopped = this.state.scriptState === _babblerScriptJs2.default.State.STOPPED || this.state.scriptState === _babblerScriptJs2.default.State.ERROR ? true : false;

        return React.createElement(
            'span',
            { style: this.props.style },
            React.createElement('input', { id: 'fileId', type: 'file', style: { display: 'none' },
                onChange: this.load_script }),
            React.createElement(
                _elemental.Button,
                { size: 'lg', type: 'primary',
                    onClick: function onClick() {
                        document.getElementById('fileId').click();
                    },
                    disabled: !stopped,
                    style: btnStyle },
                '\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044C'
            ),
            React.createElement(
                'span',
                null,
                this.state.file
            ),
            this.props.debug ? React.createElement(
                _elemental.Button,
                { size: 'lg', type: 'primary',
                    onClick: this.load_script_debug,
                    disabled: !stopped,
                    style: btnStyle },
                '\u0417\u0430\u0433\u0440\u0443\u0437\u0438\u0442\u044C (\u043E\u0442\u043B\u0430\u0434\u043A\u0430)'
            ) : "",
            this.state.err ? React.createElement(
                'span',
                null,
                React.createElement('br', null),
                React.createElement(
                    'span',
                    { style: { color: 'red' } },
                    'err: ',
                    this.state.err
                )
            ) : ""
        );
    },

    load_script: function load_script(e) {
        // https://stackoverflow.com/questions/39941583/electron-open-file-from-menu

        var files = e.target.files;
        var f = files[0];
        this.setState({ file: f.name });

        var reader = new FileReader();
        reader.onload = function (e) {
            var progStr = e.target.result;

            // распарсим строку в последовательность команд
            var prog = _babblerScriptJs2.default.parseStr(progStr).program;
            this.props.babblerScript.setProgram(prog);
        }.bind(this);
        reader.readAsBinaryString(f);

        // сбросим значение скрытого поля с именем файла, иначе
        // он не разрешит повторно загрузить тот же файл еще раз
        // (не вызовет событие onChange)
        e.target.value = "";
    },

    load_script_debug: function load_script_debug() {
        this.props.babblerScript.setProgram([{ cmd: "step", params: ["x", "10000", "1000"] }, { cmd: "step", params: ["y", "10000", "1000"] }, { cmd: "step", params: ["x", "-10000", "1000", "y", "-10000", "1000"] }]);
    }
});

// отправляем компонент на публику
module.exports = BabblerScriptLoad;
